@@ -15,6 +15,9 @@ from enum import Enum
 from purdy.animation import steps as steplib
 from purdy.parser import BlankCodeLine, parse_source
 
+#import logging
+#logger = logging.getLogger()
+
 # ===========================================================================
 # Cell Factory
 # ===========================================================================
@@ -68,7 +71,7 @@ class AnimatingCellBase:
 
     def interrupt(self, manager):
         # interrupted during an animation sequence, remove the timer
-        manager.screen.loop.remove_alarm(self.animation_alarm_handle)
+        manager.screen.remove_alarm(self.animation_alarm_handle)
 
         self.animation_alarm_handle = None
         manager.state = manager.State.ACTIVE
@@ -83,6 +86,8 @@ class GroupCell(AnimatingCellBase):
     together. Implements animation alarms so the manager can do timed call
     backs into the group and continue rendering.
     """
+    auto_forward = False
+
     def __init__(self):
         self.steps = []
         self.index = 0
@@ -117,9 +122,9 @@ class GroupCell(AnimatingCellBase):
                     continue
                 else:
                     manager.state = manager.State.SLEEPING
-                    loop = manager.screen.loop
-                    self.animation_alarm_handle = loop.set_alarm_in(step.time, 
-                            manager.screen.base_window.animation_alarm)
+                    self.animation_alarm_handle = manager.screen.set_alarm(
+                        'animation_alarm', step.time)
+
                     self.index += 1
                     return
 
@@ -149,6 +154,7 @@ class GroupCell(AnimatingCellBase):
 class TransitionCell(AnimatingCellBase):
     DELAY = 0.05
     BETWEEN_DELAY = 0.3
+    auto_forward = True
 
     class State(Enum):
         BEFORE = 0
@@ -175,6 +181,7 @@ class TransitionCell(AnimatingCellBase):
         if self.state == self.State.DONE:
             return
 
+        manager.state = manager.State.SLEEPING
         delay = self.DELAY
         if self.state == self.State.BEFORE:
             # first time through, setup our append and undo lines
@@ -185,30 +192,37 @@ class TransitionCell(AnimatingCellBase):
             self.state = self.State.DELETING
             # intentional fall through
 
-        if self.state == self.State.DELETING:
-            if self.position >= len(self.code_box.listing.lines):
-                # wiped everything, delete the empty boxes and go into append 
-                # mode
-                self.code_box.listing.clear()
-                self.state = self.State.APPENDING
-                delay = self.BETWEEN_DELAY
-            else:
-                line = BlankCodeLine()
-                self.code_box.listing.replace_line(self.position, line)
-                self.position += 1
-        else: # state == APPENDING
-            try:
-                line = self.code_lines.pop(0)
-                self.code_box.listing.insert_lines(0, [line, ])
-            except IndexError:
-                self.state = self.State.DONE
-                return
+
+        # If we're in skip mode, need to keep doing the work
+        while True:
+            if self.state == self.State.DELETING:
+                if self.position >= len(self.code_box.listing.lines):
+                    # wiped everything, delete the empty boxes and go into
+                    # append mode
+                    self.code_box.listing.clear()
+                    self.state = self.State.APPENDING
+                    delay = self.BETWEEN_DELAY
+                else:
+                    line = BlankCodeLine()
+                    self.code_box.listing.replace_line(self.position, line)
+                    self.position += 1
+            else: # state == APPENDING
+                try:
+                    line = self.code_lines.pop(0)
+                    self.code_box.listing.insert_lines(0, [line, ])
+                except IndexError:
+                    manager.state = manager.State.ACTIVE
+                    self.state = self.State.DONE
+                    manager.screen.set_alarm('auto_forward_alarm', 0)
+                    return
+
+            if not skip:
+                # Not skipping, do the loop only once and get out
+                break
 
         # ask to be woken back up for the next step
-        manager.state = manager.State.SLEEPING
-        loop = manager.screen.loop
-        self.animation_alarm_handle = loop.set_alarm_in(delay,
-            manager.screen.base_window.animation_alarm)
+        self.animation_alarm_handle = manager.screen.set_alarm(
+            'animation_alarm', delay)
 
     def undo(self, manager):
         self.state = self.State.BEFORE
