@@ -27,7 +27,7 @@ class TestSamples(TestCase):
             module.screen.load_actions(module.actions)
 
             results = []
-            for cell in module.screen.base_window.animation_manager.cells:
+            for cell in module.screen.animation_manager.cells:
                 results.append( cell._test_dict() )
 
             with open('last_output.json', 'w') as f:
